@@ -24,25 +24,40 @@ def get_current_datetime_aws_format() -> str:
     return convert_datetime_to_aws_format(datetime.now())
 
 
-def convert_country_str_to_iso_code(country_string: str) -> Optional[str]:
+def convert_country_name_to_iso_code(country_name: str) -> Optional[str]:
     """
-    Converts a country string to a 2-letter ISO 3166 Alpha-2 country code. Returns None if the country string is not
-    recognized.
-    :param country_string: input country string. E.g. United States
-    :return: 2 letter country code. E.g. US
+    Converts a country name string to a 2-letter ISO 3166 Alpha-2 country code. Returns None if the country name is
+    not recognized
+    :param country_name: input country name. E.g. United States
+    :return: 2-letter country code. E.g. US
     """
     # special handling for UK
-    if country_string == 'UK':
+    if country_name == 'UK':
         return 'GB'
 
     try:
-        possible_country_matches = countries.search_fuzzy(country_string)
+        possible_country_matches = countries.search_fuzzy(country_name)
         if len(possible_country_matches) > 0:
             return possible_country_matches[0].alpha_2
     except LookupError:
         return None
 
 
+def convert_country_iso_code_to_name(country_code: str) -> Optional[str]:
+    """
+    Converts a 2-letter ISO 3166 Alpha-2 country code to country name. Returns None if the country code is not
+    recognized
+    :param country_code: 2-letter country code. E.g. US
+    :return: country name. E.g. United States
+    """
+    try:
+        optional_country_match = countries.get(alpha_2=country_code)
+        if optional_country_match is not None:
+            return optional_country_match.name
+    except LookupError:
+        return None
+
+
 def convert_date_string_to_datetime_string(date_string: str) -> Optional[str]:
     """
     Converts a date string to a datetime string in AWS Format (YYYY-MM-DDTHH:MM:SS.SSSZ). Date string can be in the
